#
# spec file for package python-glob2
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           python-glob2
Version:        0.7
Release:        3.0.2.1.sr20240803
Summary:        Glob module recursive wildcards support
License:        BSD-2-Clause
URL:            https://pypi.python.org/pypi/glob2
Source:         https://files.pythonhosted.org/packages/source/g/glob2/glob2-%{version}.tar.gz
# PATCH-FIX-UPSTREAM gh#miracle2k/python-glob2#31
Patch0:         support-pytest-8.patch
BuildRequires:  %{python_module pip}
BuildRequires:  %{python_module pytest}
BuildRequires:  %{python_module setuptools}
BuildRequires:  %{python_module wheel}
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
BuildArch:      noarch

%python_subpackages

%description
This module provides an extended version of Python's builtin glob
module with the following additions:

- The ability to capture the text matched by glob patterns, and
  return those matches alongside the filenames.
- A recursive '**' globbing syntax, akin for example to the globstar
  option of the bash shell.
- The ability to replace the filesystem functions used, in order to
  glob on virtual filesystems.

%prep
%autosetup -p1 -n glob2-%{version}

%build
%pyproject_wheel

%install
%pyproject_install
%python_expand %fdupes %{buildroot}%{$python_sitelib}

%check
%pytest test.py

%files %{python_files}
%license LICENSE
%doc README.rst CHANGES
%{python_sitelib}/glob2
%{python_sitelib}/glob2-%{version}.dist-info

%changelog
* Mon Aug 26 2024 Steve Kowalik <steven.kowalik@suse.com>
- Switch to autosetup and pyproject macros.
- No more greedy globs in %%files.
- Add patch support-pytest-8.patch:
  * Use correct setup/teardown methods for Pytest 8.
* Thu Mar 26 2020 Paolo Stivanin <info@paolostivanin.com>
- Switch from nose to pytest
* Wed Jun 19 2019 pgajdos@suse.com
- version update to 0.7
  * Fix deprecation warning.
* Thu Mar 21 2019 John Vandenberg <jayvdb@gmail.com>
- Remove unnecessary build dependency on python-devel
* Tue May 22 2018 bruno@ioda-net.ch
- spec-cleaner (date/url)
- Use only %%license
* Wed Oct  4 2017 bruno@ioda-net.ch
- Backport to singlespec
- spec-cleanup (Mostly Year)
- Remove Source1 (LICENSE) is now included in tar.gz
- Update to bugfix version 0.6
  - Support dummy recursive parameter in APIs to match the new
    call signature of Python 3.
  - Fix lru_cache (Kostis Anagnostopoulos).
  - Introduce norm_paths and case_sensitive options to optionally
    change the behaviour (Kostis Anagnostopoulos).
  + 0.5 (2016-11-04)
  - include_hidden option.
  - Python 3 fixes.
  - Publish a wheel.
* Mon Jun 13 2016 toddrme2178@gmail.com
- Don't check unit test coverage.
* Sun May  8 2016 arun@gmx.de
- specfile:
  * updated source url to files.pythonhosted.org
* Sun Mar 13 2016 bruno@ioda-net.ch
- Create python3 packaging
- Added missing LICENSE file in tar.gz from github
  Upstream gh/issue/11
